# Used in the paper for producing Figure 7
# (confidence intervals for training conditional error probabilities)

library(Hmisc)

# These are the overall errors on the test set for the first 8 seeds
counts <- c(41,69,46,54,53,61,77,59)   # seeds 0 - 7
# counts <- c(67,55,68,41,32,61,47,62)   # seeds 8 - 15
# counts <- c(65,50,46,42,46,53,42,58)     # seeds 16 - 22

# Confidence intervals at 95%
result95 <- binconf(counts,1000,alpha=0.05)    # default (considered better)
# result95 <- binconf(counts,1000,alpha=0.05,method="exact")
lower95 <- result95[,2]
upper95 <- result95[,3]

# Confidence intervals at 80%
result80 <- binconf(counts,1000,alpha=0.20)    # default (considered better)
# result80 <- binconf(counts,1000,alpha=0.20,method="exact")
lower80 <- result80[,2]
upper80 <- result80[,3]

par(mar=c(4,4,1,1))   # smaller margins (the default, (6,4,4,2), is too big unless I need labels for axes and a title)
plot(c(-0.5,7.5),c(0,0.1),xlab="seed",ylab="confidence interval",type="n",xaxp=c(0,7,7))
lines(c(-1,8),c(0.05,0.05),col="red")  # the 5% level
for (i in 0:7) {
  lines(c(i,i),c(lower80[i+1],upper80[i+1]),col="blue",lwd=3)
  lines(c(i,i),c(lower95[i+1],upper95[i+1]))
}
